@@ -941,9 +941,9 @@ static void empty_label_msg (void)
     }
 
     g_autofree gchar *label_txt = g_strdup_printf ("<b>%s</b>\n\n%s", msg_substr, 
-                                                   _("Existing menus with invisible menu elements may be opened; "
-                                                     "these menu elements can be visualized or deleted at once, "
-                                                     "otherwise they are highlighted."));
+                                                   _("Menu files with invisible elements can be opened. "
+                                                     "During the loading phase, the user can choose to either visualize or delete all these elements all at once. "
+                                                     "If not addressed at this stage, they will be highlighted afterward."));
 
     show_message_dialog (_("Entry of Empty Label Blocked"), "dialog-error", label_txt, _("_Close"));
 }
